@@ -4,8 +4,5 @@ from .mixins import CommonMixin, NameMixin, PrintMixin
 
 class DestService(CommonMixin, NameMixin, PrintMixin):
     def __init__(self, base: BaseService) -> None:
-
-        # init mixins
-        CommonMixin.__init__(self, base)
-
+        super().__init__(base=base)
         self.endpoint = "/api/destinations"
